Acknowledgements
================

TRAW draws heavily from the following projects:

`testrail-python <https://github.com/travispavek/testrail-python>`_
-------------------------------------------------------------------

TRAW's object models and client interface is largely based off of testrail-python's models and client interface

`PRAW - Python Reddit API Wrapper <https://github.com/praw-dev/praw>`_
----------------------------------------------------------------------

TRAW's HTTP request scheme is based off a slimmed down version of PRAW's use of requests.sessions
